.. pyprefab documentation master file, created by
   sphinx-quickstart on Wed Feb  5 14:13:05 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. toctree::
   :hidden:
   :maxdepth: 3
   :caption: Contents:

   usage
   CONTRIBUTING
   CHANGELOG

.. include:: readme.md
   :parser: myst_parser.sphinx_
